#ifndef NT2_INCLUDE_FUNCTIONS_LOOKUP_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LOOKUP_HPP_INCLUDED

#include <nt2/swar/include/functions/lookup.hpp>

#endif
